@@ -15,7 +15,12 @@
 #include "kmessageclient.h"
 #include "kmessageio.h"
 // KF
+#include <kdnssd_version.h>
+#if KDNSSD_VERSION >= QT_VERSION_CHECK(5, 84, 0)
+#include <KDNSSD/PublicService>
+#else
 #include <DNSSD/PublicService>
+#endif
 // Qt
 #include <QBuffer>
 #include <QList>
